@@ -1,6 +1,8 @@
 from typing import Callable
 import cv2
 import numpy as np
+from typing import Optional
+
 
 class InvalidInputError(Exception): ...
 
@@ -33,8 +35,7 @@ class VideoStreamer:
            window_name=window_name, 
            waitkey=waitkey 
        )
-    
-    def on_next_frame(self, func:Callable[[np.ndarray], None]):
+    def on_next_frame(self, shape:Optional[tuple[int,int]]=None):
         """
         Use as a decorator to wrap your function\n
         The cam window is drawn automatically after the function has been called.\n
@@ -47,7 +48,14 @@ class VideoStreamer:
 
 
         """
-        self.__tasks.append(func)  
+        if not shape is None:
+           self.__tasks.append(lambda img: cv2.resize(img, shape, interpolation=cv2.INTER_AREA))
+           
+        def inner(func:Callable[[np.ndarray], None]):
+            self.__tasks.append(func)  
+
+        return inner    
+
         
     def from_video_input(path, window_name="video", waitkey=1):
 
